# Copyright (c) 2000-2008, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_with maven

%define _without_gcj_support 1
%define gcj_support %{?_with_gcj_support:1}%{!?_with_gcj_support:%{?_without_gcj_support:0}%{!?_without_gcj_support:%{?_gcj_support:%{_gcj_support}}%{!?_gcj_support:0}}}

%define base_name  validator
%define short_name commons-%{base_name}
%define section    free

Name:           jakarta-%{short_name}
Version:        1.3.1
Release:	7.5%{?dist}
Epoch:          0
Summary:        Jakarta Commons Validator
License:        ASL 2.0
Group:          Development/Libraries/Java
URL:            http://commons.apache.org/validator/
Source0:        http://www.apache.org/dist/jakarta/commons/validator/source/commons-validator-%{version}-src.tar.gz
Source1:        %{name}.catalog
Source2:        maven2jpp-mapdeps.xsl
Source3:        commons-validator-1.3.1-jpp-depmap.xml
Source4:        http://repo1.maven.org/maven2/commons-validator/commons-validator/1.3.1/commons-validator-1.3.1.pom
Patch0:         commons-validator-1.3.1.patch
Requires(post): jpackage-utils >= 0:1.7.3
Requires(postun):  jpackage-utils >= 0:1.7.3
Requires:       java >= 0:1.5.0
Requires:       jakarta-commons-beanutils >= 0:1.7
Requires:       jakarta-commons-collections >= 0:3.1
Requires:       jakarta-commons-digester >= 0:1.7
Requires:       jakarta-commons-logging >= 0:1.1
Requires:       oro >= 0:2.0.8
Requires:       xml-commons-jaxp-1.3-apis
BuildRequires:  jpackage-utils >= 0:1.7.3
BuildRequires:  java-devel >= 0:1.5.0
BuildRequires:  ant >= 0:1.6.5
%if %with maven
BuildRequires:  maven >= 0:1.1
BuildRequires:  maven-plugins-base
BuildRequires:  maven-plugin-changelog
BuildRequires:  maven-plugin-changes
BuildRequires:  maven-plugin-javadoc
BuildRequires:  maven-plugin-license
BuildRequires:  maven-plugin-test
BuildRequires:  maven-plugin-xdoc
BuildRequires:  saxon
BuildRequires:  saxon-scripts
BuildRequires:  sf-cobertura-maven-plugin
%endif
BuildRequires:  jakarta-commons-beanutils >= 0:1.7
BuildRequires:  jakarta-commons-collections >= 0:3.1
BuildRequires:  jakarta-commons-digester >= 0:1.7
BuildRequires:  jakarta-commons-logging >= 0:1.1
BuildRequires:  junit >= 0:3.8.1
BuildRequires:  oro >= 0:2.0.8
BuildRequires:  rhino16
BuildRequires:  xml-commons-jaxp-1.3-apis
Requires:       java >= 0:1.5.0
Requires:       jakarta-commons-beanutils >= 0:1.7
Requires:       jakarta-commons-collections >= 0:3.1
Requires:       jakarta-commons-digester >= 0:1.7
#Requires:       jakarta-commons-logging >= 0:1.1
Requires:       jakarta-commons-logging
Requires:       oro >= 0:2.0.8
Requires:       xml-commons-jaxp-1.3-apis
%if ! %{gcj_support}
BuildArch:      noarch
%endif
%if %{gcj_support}
BuildRequires:    java-gcj-compat-devel
%endif
Requires(post):    jpackage-utils >= 0:1.7.3
Requires(postun):  jpackage-utils >= 0:1.7.3
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
A common issue when receiving data either electronically or from user
input is verifying the integrity of the data. This work is repetitive
and becomes even more complicated when different sets of validation
rules need to be applied to the same set of data based on locale for
example. Error messages may also vary by locale. This package attempts
to address some of these issues and speed development and maintenance
of validation rules.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
Javadoc for %{name}.

%prep
%setup -q -n %{short_name}-%{version}-src
cp -p %{SOURCE1} conf/share/catalog

# remove all binary libs
find . -name "*.jar"

%patch0 -b .sav0

%build
%if %with maven
for p in $(find . -name project.xml); do
    pushd $(dirname $p)
    cp -p project.xml project.xml.orig
    %{_bindir}/saxon -o project.xml project.xml.orig %{SOURCE2} map=%{SOURCE3}
    popd
done

export MAVEN_HOME_LOCAL=$(pwd)/.maven
mkdir -p $MAVEN_HOME_LOCAL/repository/

maven -e \
        -Dmaven.home.local=$MAVEN_HOME_LOCAL \
        -Dmaven.repo.remote=file:/usr/share/maven/repository \
        jar:install javadoc
%else
export CLASSPATH=
export OPT_JAR_LIST=:
ant \
    -Dcommons-beanutils.jar=$(build-classpath commons-beanutils) \
    -Dcommons-collections.jar=$(build-classpath commons-collections) \
    -Dcommons-digester.jar=$(build-classpath commons-digester) \
    -Dcommons-logging.jar=$(build-classpath commons-logging) \
    -Doro.jar=$(build-classpath oro) \
    -Djunit.jar=$(build-classpath junit) \
    -Ddojo_custom_rhino.jar=$(build-classpath rhino16) \
    test dist
%endif

for i in `%{_bindir}/find -type f -name "*-compress.js"`; do
    if ! %{__grep} -q "^function " "$i"; then
        exit 1
    fi
done

%install
rm -rf $RPM_BUILD_ROOT

# jars
mkdir -p $RPM_BUILD_ROOT%{_javadir}
%if %with maven
install -m 644 target/%{short_name}-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
%else
install -m 644 dist/%{short_name}-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
%endif
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}*; do ln -sf ${jar} `echo $jar| sed "s|jakarta-||g"`; done)
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}*; do ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`; done)

%add_to_maven_depmap %{short_name} %{short_name} %{version} JPP %{short_name}

# pom
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/maven2/poms
install -p -m 644 %{SOURCE4} $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{short_name}.pom

# dtds and catalog
mkdir -p $RPM_BUILD_ROOT%{_datadir}/sgml/%{name}
cp -p conf/share/{*.dtd,catalog} $RPM_BUILD_ROOT%{_datadir}/sgml/%{name}

# javadoc
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
%if %with maven
cp -pr target/docs/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
%else
cp -pr dist/docs/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
%endif
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}

mkdir -p %{buildroot}%{_sysconfdir}/sgml
touch $RPM_BUILD_ROOT%{_sysconfdir}/sgml/%{name}-%{version}-%{release}.cat

%if %{gcj_support}
%{_bindir}/aot-compile-rpm
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post
%update_maven_depmap
# Note that we're using versioned catalog, so this is always ok.
/bin/touch %{_sysconfdir}/sgml/%{name}-%{version}-%{release}.cat 2>/dev/null
if [ -x %{_bindir}/install-catalog -a -d %{_sysconfdir}/sgml ]; then
  %{_bindir}/install-catalog --add \
    %{_sysconfdir}/sgml/%{name}-%{version}-%{release}.cat \
    %{_datadir}/sgml/%{name}/catalog > /dev/null 2>&1 || :
fi
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%postun
%update_maven_depmap
# Note that we're using versioned catalog, so this is always ok.
if [ -x %{_bindir}/install-catalog -a -d %{_sysconfdir}/sgml ]; then
  %{_bindir}/install-catalog --remove \
    %{_sysconfdir}/sgml/%{name}-%{version}-%{release}.cat \
    %{_datadir}/sgml/%{name}/catalog > /dev/null 2>&1 || :
fi
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%files
%defattr(0644,root,root,0755)
%doc LICENSE.txt NOTICE.txt
%{_javadir}/%{name}-%{version}.jar
%{_javadir}/%{name}.jar
%{_javadir}/%{short_name}.jar
%{_javadir}/%{short_name}-%{version}.jar
%{_datadir}/sgml/%{name}
%{_datadir}/maven2/*
%{_mavendepmapfragdir}/*
%ghost %{_sysconfdir}/sgml/%{name}-%{version}-%{release}.cat
%if %{gcj_support}
%dir %{_libdir}/gcj/%{name}
%attr(-,root,root) %{_libdir}/gcj/%{name}/*
%endif

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%changelog
* Thu May 14 2009 Martha Benitez <mbenitez@redhat.com> 1.3.1-7.5
- Merge from RHEL4

* Thu Feb 26 2009 Permaine Cheung <pcheung@redhat.com> 1.3.1-7.1
- Build without gcj support

* Thu Jan 29 2009 Martha Benitez <mbenitez@redhat.com>
- Change jpackage-utils >= 0:1.7.4 to jpackage-utils >= 0:1.7.3
- Remove version requirement for jakarta-commons-logging >= 0:1.1
- Add jakarta-commons-collections to classpath
- Add commons-collection patch to build.xml

* Mon Dec 08 2008 Will Tatam <will.tatam@red61.com> 1.3.1-7
- Auto rebuild for JPackage 5 in mock

* Fri Dec 05 2008 David Walluck <dwalluck@redhat.com> 0:1.3.1-6
- fix catalog install
- use explicit file list for jars

* Fri Aug 22 2008 David Walluck <dwalluck@redhat.com> 0:1.3.1-4
- really relax version requirement for jakarta-commons-collections
- add javadoc symlink

* Wed Jul 30 2008 David Walluck <dwalluck@redhat.com> 0:1.3.1-3
- build without maven by default
- set OPT_JAR_LIST as empty
- relax version requirement for jakarta-commons-collections
- update License
- update BuildRoot
- remove javadoc scriptlets
- fix maven directory ownership
- use macros
- GCJ fixes

* Fri Feb 01 2008 Ralph Apel <r.apel at r-apel.de> -  0:1.3.1-2jpp
- Extend catalog
- Build with maven1 by default
- Add poms and depmap frags
- Fix gcj_support build
- Don't set CLASSPATH
- Always test

* Thu Jan 03 2008 Ralph Apel <r.apel at r-apel.de> -  0:1.3.1-1jpp
- 1.3.1

* Fri Aug 18 2006 Deepak Bhole <dbhole at redhat.com> -  0:1.1.4-5jpp
- Move rebuild-gcj-db to correct postun section

* Tue Aug 15 2006 Deepak Bhole <dbhole at redhat.com> -  0:1.1.4-4jpp
- Added missing post/postun for javadoc.

* Tue Jul 25 2006 Deepak Bhole <dbhole at redhat.com> -  0:1.1.4-3jpp
- Added conditional native compilation.
- Converted spec file to UTF8.

* Wed Apr 26 2006 Fernando Nasser <fnasser at redhat.com> - 0:1.1.4-2jpp
- First JPP 1.7 build

* Tue Jul 26 2005 Fernando Nasser <fnasser at redhat.com> - 0:1.1.4-1jpp
- Upgrade to 1.1.4

* Tue Sep 07 2004 Fernando Nasser <fnasser at redhat.com> - 0:1.1.3-1jpp
- Upgrade to 1.1.3

* Sun Aug 23 2004 Randy Watler <rwatler at finali.com> - 0:1.0.2-3jpp
- Rebuild with ant-1.6.2

* Fri Apr 18 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:1.0.2-2jpp
- Move DTDs from %%{_datadir}/%{name} to %%{_datadir}/sgml/%%{name} for FHS
  compliance, <http://www.pathname.com/fhs/2.2/fhs-4.11.html#4.11.7>.

* Fri Apr 18 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:1.0.2-1jpp
- Update to 1.0.2 and JPackage 1.5.
- Move DTDs from %%doc to %%{_datadir}/%%{name}.
- Include catalog for DTDs, and install it if %%{_bindir}/install-catalog
  is available.

* Mon Dec 16 2002 Ville Skyttä <ville.skytta at iki.fi> - 1.0.1-1jpp
- 1.0.1.
- Include the DTD in the package (as documentation).

* Sat Nov  2 2002 Ville Skyttä <ville.skytta at iki.fi> - 1.0-1jpp
- 1.0, initial JPackage release.
